"use client";
import { useState, useEffect } from "react";
import { ThemeProvider } from "@context/index";
import Loading from "./loading";
import "./globals.css";

export default function RootLayout({ children, header }) {
  const [themeClass, setThemeClass] = useState("loading");

  useEffect(() => {
    // Check if localStorage is available (client-side)
    const storedThemeClass =
      typeof window !== "undefined" ? localStorage.getItem("theme") : "";

    // Simulate an asynchronous operation (e.g., fetching theme data)
    setTimeout(() => {
      // Set the theme class, or use a default value if not found
      setThemeClass(storedThemeClass || "defaultTheme");
    }, 1000); // Adjust the delay as needed
  }, []); // Empty dependency array ensures the effect runs once, similar to componentDidMount

  return (
    <ThemeProvider>
      <html lang="en" className={themeClass}>
        <body>
          {themeClass === "loading" ? (
            <Loading />
          ) : (
            <div id="root">
              {header}
              {children}
            </div>
          )}
        </body>
      </html>
    </ThemeProvider>
  );
}
